package com.mcwl.web.controller.memberCenter;

import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.memberCenter.domain.MemberBenefit;
import com.mcwl.memberCenter.domain.MemberLevel;
import com.mcwl.memberCenter.service.MemberBenefitService;
import com.mcwl.memberCenter.service.MemberLevelService;
import com.mcwl.memberCenter.domain.vo.MemberBenefitVO;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("memberLevel")
@RequiredArgsConstructor
public class MemberLevelController {

    private final MemberLevelService memberLevelService;

    private final MemberBenefitService memberBenefitService;

    /**
     * 获取会员等级列表
     *
     * @return 会员等级列表
     */
    @GetMapping("list")
    public AjaxResult list() {

        List<MemberLevel> memberLevelList = memberLevelService.list();

        return AjaxResult.success(memberLevelList);
    }


    /**
     * 获取会员等级及权益列表
     */
    @GetMapping("getMemberBenefitList")
    public AjaxResult getMemberBenefitList() {

        List<MemberBenefitVO> memberBenefitVOList = new ArrayList<>();

        List<MemberLevel> memberLevelList = memberLevelService.list();
        for (MemberLevel memberLevel : memberLevelList) {
            MemberBenefitVO memberBenefitVO = new MemberBenefitVO();
            memberBenefitVO.setMemberLevel(memberLevel);
            // 获取会员等级对应的权益
            List<MemberBenefit> memberBenefitList = memberBenefitService.lambdaQuery()
                    .eq(MemberBenefit::getMemberLevelId, memberLevel.getId())
                    .list();
            memberBenefitVO.setMemberBenefitList(memberBenefitList);
            memberBenefitVOList.add(memberBenefitVO);
        }

        return AjaxResult.success(memberBenefitVOList);
    }

}
