package com.mcwl.memberCenter.consumer;

import com.mcwl.common.constant.QueueConstants;
import com.mcwl.memberCenter.domain.Member;
import com.mcwl.memberCenter.service.MemberService;
import com.rabbitmq.client.Channel;
import org.springframework.amqp.core.Message;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * 积分消费者
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class EmptyPointsRemindConsumer {

    private final MemberService memberService;

    /**
     * 积分清零提醒
     */
    @RabbitListener(queues = QueueConstants.EMPTY_POINTS_REMIND_QUEUE, ackMode = "MANUAL")
    public void emptyPointsRemind(Member Member, Channel channel, Message message) {
        try {
            // TODO 发送短信提醒用户积分即将清零
            log.info("获取到积分清零提醒的数据:{}", Member);
            channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
        } catch (Exception e) {
            log.error("处理积分清零提醒消息时出错: {}", e.getMessage(), e);
            try {
                channel.basicNack(message.getMessageProperties().getDeliveryTag(), false, true);
            } catch (IOException ex) {
                log.error("消息确认失败: {}", ex.getMessage(), ex);
            }
        }
    }


}
