package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.MallProduct;
import com.mcwl.resource.domain.MallProductLike;
import com.mcwl.resource.domain.vo.MallProductVo;
import com.mcwl.resource.mapper.MallProductLikeMapper;
import com.mcwl.resource.service.MallProductLikeService;
import com.mcwl.resource.service.MallProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @author DaiZibo
 * @date 2025/1/2
 * @apiNote
 */

@Service
public class MallProductLikeServiceImpl implements MallProductLikeService {

    @Autowired
    private MallProductLikeMapper mallProductLikeMapper;

    @Autowired
    private MallProductService mallProductService;

    @Override
    public Page<MallProduct> selectByUserLike(MallProductVo mallProductVo) {

        //获取登录人
        Long userId = SecurityUtils.getUserId();
        List<Long> list = mallProductLikeMapper.selectByUserId(userId);

        //分页查询作品数据
        return mallProductService.pageLike(mallProductVo, list);
    }

    @Override
    public AjaxResult addLike(Long productId) {

        Boolean aBoolean = selectLike(productId);
        if (aBoolean == true){
            //删除点赞记录
            mallProductLikeMapper.deleteByUserIdAndProductId(productId,SecurityUtils.getUserId());
            return AjaxResult.success(false);
        }

        MallProductLike mallProductLike = MallProductLike.builder().productId(productId)
                .userId(SecurityUtils.getUserId())
                .createName(SecurityUtils.getUsername())
                .createTime(new Date()).build();

        int insert = mallProductLikeMapper.insert(mallProductLike);

        if (insert<0){

            return AjaxResult.error("点赞失败",false);
        }
        return AjaxResult.success(true);
    }

    @Override
    public AjaxResult deleteLike(Long productId) {

        return AjaxResult.success();
    }

    @Override
    public Boolean selectLike(Long productId) {

        MallProductLike mallProductLike1 = mallProductLikeMapper.selectByUserIdAndProductId(SecurityUtils.getUserId(),productId);

        if (mallProductLike1 == null){

            return false;
        }
        return true;
    }

}
