package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.MallProduct;
import com.mcwl.resource.mapper.MallProductMapper;
import com.mcwl.resource.service.MallProductService;
import com.mcwl.resource.domain.vo.MallProductVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.resource.service.impl
 * @Filename：MallProductServiceImpl
 * @Description TODO
 * @Date：2024/12/30 18:22
 */
@Service
public class MallProductServiceImpl extends ServiceImpl<MallProductMapper,MallProduct> implements MallProductService {

    @Autowired
    private MallProductMapper postMapper;


    @Override
    public List<MallProduct> selectMallProductList(MallProduct mallProduct) {
        QueryWrapper<MallProduct> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(MallProduct::getProductName, mallProduct.getProductName());
        queryWrapper.lambda().eq(MallProduct::getName, mallProduct.getName());
        queryWrapper.lambda().eq(MallProduct::getAmount, mallProduct.getAmount());
        return postMapper.selectList(queryWrapper);
    }

    @Override
    public String selectMallProductById(Long mallProductId) {
        return postMapper.selectMallProductById(mallProductId);
    }

    @Override
    public int insertMallProduct(MallProduct mallProduct) {
        return postMapper.insert(mallProduct);
    }

    @Override
    public int updateMallProduct(MallProduct mallProduct) {
        return postMapper.updateById(mallProduct);
    }

    @Override
    public void deleteMallProductByIds(IdsParam ids) {
        postMapper.deleteBatchIds(ids.getIds());
    }

    @Override
    public Page<MallProduct> selectByUserId(MallProductVo mallProductVo) {

        // 创建分页对象
        Page<MallProduct> mallProductPage = new Page<>(mallProductVo.getPageNumber(), mallProductVo.getPageSize());

        //获取当前登录人ID
        Long userId = SecurityUtils.getUserId();
        LambdaQueryWrapper<MallProduct> mallProductLambdaQueryWrapper = new LambdaQueryWrapper<>();

        mallProductLambdaQueryWrapper.eq(MallProduct::getUserId,userId);
        mallProductLambdaQueryWrapper.eq(MallProduct::getDelFlag,0);

        if (mallProductVo.getStatus() != 0){
            mallProductLambdaQueryWrapper.eq(MallProduct::getStatus,mallProductVo.getStatus());
        }

        if (mallProductVo.getOrder() == 1){
            mallProductLambdaQueryWrapper.orderByDesc(MallProduct::getProductId);
        }else {
            mallProductLambdaQueryWrapper.orderByDesc(MallProduct::getNumber);
        }

        // 开始时间和结束时间过滤
        if (mallProductVo.getStartTime() != null && mallProductVo.getEndTime() != null) {
            // 查询开始时间和结束时间之间的商品
            mallProductLambdaQueryWrapper.between(MallProduct::getCreateTime, mallProductVo.getStartTime(), mallProductVo.getEndTime());
        } else if (mallProductVo.getStartTime() != null) {
            // 只有开始时间，查询大于等于开始时间的商品
            mallProductLambdaQueryWrapper.ge(MallProduct::getCreateTime, mallProductVo.getStartTime());
        } else if (mallProductVo.getEndTime() != null) {
            // 只有结束时间，查询小于等于结束时间的商品
            mallProductLambdaQueryWrapper.le(MallProduct::getCreateTime, mallProductVo.getEndTime());
        }

        return postMapper.selectPage(mallProductPage, mallProductLambdaQueryWrapper);
    }

    @Override
    public Page<MallProduct> pageLike(MallProductVo mallProductVo, List<Long> list) {

        // 创建分页对象
        Page<MallProduct> mallProductPage = new Page<>(mallProductVo.getPageNumber(), mallProductVo.getPageSize());

        LambdaQueryWrapper<MallProduct> mallProductLambdaQueryWrapper = new LambdaQueryWrapper<>();
        mallProductLambdaQueryWrapper.in(MallProduct::getProductId,list);

        if (mallProductVo.getOrder() == 1){
            mallProductLambdaQueryWrapper.orderByDesc(MallProduct::getProductId);
        }else {
            mallProductLambdaQueryWrapper.orderByDesc(MallProduct::getNumber);
        }

        return postMapper.selectPage(mallProductPage,mallProductLambdaQueryWrapper);
    }


}
